extends Node2D

onready var box = $Box
onready var icon = $Icon
onready var label = $Label

func _process(delta: float) -> void:
	# boxを移動・回転する
	if Input.is_action_pressed("ui_left"):
		#box.position.x -= 5
		box.rotation_degrees -= 3
	if Input.is_action_pressed("ui_up"):
		box.position.y -= 5
	if Input.is_action_pressed("ui_right"):
		#box.position.x += 5
		box.rotation_degrees += 3
	if Input.is_action_pressed("ui_down"):
		box.position.y += 5

	# 衝突チェック	
	label.text = ""
	if _is_hit(box, icon):
		# 衝突している
		label.text = "hit"

# スプライト同士が衝突しているかどうか
func _is_hit(spr1:Sprite, spr2:Sprite) -> bool:
	# Spriteの画像データを頂点として取得する
	var v1 = _spr_to_vec2array(spr1)
	var v2 = _spr_to_vec2array(spr2)
	
	if Geometry.intersect_polygons_2d(v1, v2):
		# 衝突している
		return true
	
	return false;

# スプライトから頂点リストを作る
func _spr_to_vec2array(spr:Sprite) -> PoolVector2Array:
	var ret = PoolVector2Array()
	
	var pos:Vector2 = spr.position
	var rect:Rect2 = spr.get_rect()
	# スケールを反映
	var w  = rect.size.x * spr.scale.x
	var h  = rect.size.y * spr.scale.y
	var w2 = w / 2
	var h2 = h / 2
	
	var v1 = Vector2(0, 0) # 左上
	var v2 = Vector2(w, 0) # 右上
	var v3 = Vector2(w, h) # 右下
	var v4 = Vector2(0, h) # 左下
	if spr.centered:
		# 中央揃え
		v1 = Vector2(-w2, -h2) # 左上
		v2 = Vector2( w2, -h2) # 右上
		v3 = Vector2( w2,  h2) # 右下
		v4 = Vector2(-w2,  h2) # 左下
		
	# 回転(ラジアン)を求める	
	var rad = spr.rotation
	ret.push_back(pos + v1.rotated(rad))
	ret.push_back(pos + v2.rotated(rad))
	ret.push_back(pos + v3.rotated(rad))
	ret.push_back(pos + v4.rotated(rad))
	
	return ret
